# utilidades_dados

Description. 
The package utilidades_dados is used to:

	OPERACOES:
	- metade
	- dobro
	- aumento
	- diminui
	- moeda
	- tabelaform
	- resumo

	TRATAMENTO_DADOS:
	- filtrodados
	- adicionar_coluna_dados
	- taxa_evolucao 

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install utilidades_dados

```bash
pip install utilidades_dados
```

## Author
Danilo Caiena

## License
[MIT](https://choosealicense.com/licenses/mit/)# utilidade-dados-package
# utilidade-dados-package
